@@ -24,7 +24,7 @@ item_replace_files <- function(sb_id, files, ..., all=FALSE,
 	if(all){
 		item <- item_rm_files(sb_id, ...)
 	}else{
-		item <- item_rm_files(sb_id, files, ...)
+		item <- item_rm_files(sb_id, basename(files), ...)
 	}
 	
 	if(!is.null(item))
