@@ -13,13 +13,8 @@ test_that("generic get w/ and w/o auth", {
 	skip_on_cran()
 	
 	public_item <- '5c081d14e4b0815414d0346c' # public read access
-	non_item <-     '4f4e4a62e4b0a92fa7e9cf36' # made-up ID
-	#private_item <- '55569325e4b0a92fa7e9cf36' # private to whom? can we test with a session that has access and yet is Travis-runable?
-	
+
 	# public access to public items, with or without login
 	expect_s3_class(item_get(public_item), 'sbitem')
 	
-	# 'not found' error for missing items, with or without login
-	expect_warning(expect_warning(item_get(non_item)))
-	
 })
